# Lefaire

## Application de gestion de tâches pour le terminal

### Installation

Pour installer Lefaire : `pip install lefaire`

### Configuration

Afin de pouvoir fonctionner Lefaire doit se connecter à une base de données MariaDB.

Pour effectuer la configuration, entrez dans votre terminal `lefaire init`.
Puis renseignez le mot de passe root de MariaDB ainsi que l'host.

### Commandes

`lefaire --help` vous renseignera sur toutes les commandes
